# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['TrafficSelectorArgs', 'TrafficSelector']

@pulumi.input_type
class TrafficSelectorArgs:
    def __init__(__self__, *,
                 destination_address: pulumi.Input[str],
                 name: pulumi.Input[str],
                 source_address: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 destination_port: Optional[pulumi.Input[int]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[int]] = None,
                 ipsec_policy: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 source_port: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a TrafficSelector resource.
        :param pulumi.Input[str] destination_address: Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[str] name: Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        :param pulumi.Input[str] source_address: Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[str] description: Description of the traffic selector.
        :param pulumi.Input[int] destination_port: Specifies the IP port used by the application. The default value is `All Ports (0)`
        :param pulumi.Input[str] direction: Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        :param pulumi.Input[int] ip_protocol: Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        :param pulumi.Input[str] ipsec_policy: Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        :param pulumi.Input[int] order: Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
               When creating a new traffic selector, if this parameter is not specified, the default is `last`
        :param pulumi.Input[int] source_port: Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        pulumi.set(__self__, "destination_address", destination_address)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "source_address", source_address)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if direction is not None:
            pulumi.set(__self__, "direction", direction)
        if ip_protocol is not None:
            pulumi.set(__self__, "ip_protocol", ip_protocol)
        if ipsec_policy is not None:
            pulumi.set(__self__, "ipsec_policy", ipsec_policy)
        if order is not None:
            pulumi.set(__self__, "order", order)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)

    @property
    @pulumi.getter(name="destinationAddress")
    def destination_address(self) -> pulumi.Input[str]:
        """
        Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "destination_address")

    @destination_address.setter
    def destination_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "destination_address", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sourceAddress")
    def source_address(self) -> pulumi.Input[str]:
        """
        Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "source_address")

    @source_address.setter
    def source_address(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_address", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the traffic selector.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "destination_port", value)

    @property
    @pulumi.getter
    def direction(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        """
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        """
        return pulumi.get(self, "ip_protocol")

    @ip_protocol.setter
    def ip_protocol(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ip_protocol", value)

    @property
    @pulumi.getter(name="ipsecPolicy")
    def ipsec_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        """
        return pulumi.get(self, "ipsec_policy")

    @ipsec_policy.setter
    def ipsec_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipsec_policy", value)

    @property
    @pulumi.getter
    def order(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
        When creating a new traffic selector, if this parameter is not specified, the default is `last`
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "order", value)

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "source_port", value)


@pulumi.input_type
class _TrafficSelectorState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_address: Optional[pulumi.Input[str]] = None,
                 destination_port: Optional[pulumi.Input[int]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[int]] = None,
                 ipsec_policy: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 source_address: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering TrafficSelector resources.
        :param pulumi.Input[str] description: Description of the traffic selector.
        :param pulumi.Input[str] destination_address: Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] destination_port: Specifies the IP port used by the application. The default value is `All Ports (0)`
        :param pulumi.Input[str] direction: Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        :param pulumi.Input[int] ip_protocol: Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        :param pulumi.Input[str] ipsec_policy: Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        :param pulumi.Input[str] name: Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        :param pulumi.Input[int] order: Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
               When creating a new traffic selector, if this parameter is not specified, the default is `last`
        :param pulumi.Input[str] source_address: Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] source_port: Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_address is not None:
            pulumi.set(__self__, "destination_address", destination_address)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if direction is not None:
            pulumi.set(__self__, "direction", direction)
        if ip_protocol is not None:
            pulumi.set(__self__, "ip_protocol", ip_protocol)
        if ipsec_policy is not None:
            pulumi.set(__self__, "ipsec_policy", ipsec_policy)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if order is not None:
            pulumi.set(__self__, "order", order)
        if source_address is not None:
            pulumi.set(__self__, "source_address", source_address)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Description of the traffic selector.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationAddress")
    def destination_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "destination_address")

    @destination_address.setter
    def destination_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_address", value)

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "destination_port", value)

    @property
    @pulumi.getter
    def direction(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        """
        return pulumi.get(self, "direction")

    @direction.setter
    def direction(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "direction", value)

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        """
        return pulumi.get(self, "ip_protocol")

    @ip_protocol.setter
    def ip_protocol(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ip_protocol", value)

    @property
    @pulumi.getter(name="ipsecPolicy")
    def ipsec_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        """
        return pulumi.get(self, "ipsec_policy")

    @ipsec_policy.setter
    def ipsec_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ipsec_policy", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def order(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
        When creating a new traffic selector, if this parameter is not specified, the default is `last`
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "order", value)

    @property
    @pulumi.getter(name="sourceAddress")
    def source_address(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "source_address")

    @source_address.setter
    def source_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_address", value)

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "source_port", value)


class TrafficSelector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_address: Optional[pulumi.Input[str]] = None,
                 destination_port: Optional[pulumi.Input[int]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[int]] = None,
                 ipsec_policy: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 source_address: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        `TrafficSelector` Manage IPSec Traffic Selectors on BIG-IP

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/test-selector)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_selector = f5bigip.TrafficSelector("test-selector",
            name="/Common/test-selector",
            destination_address="3.10.11.2/32",
            source_address="2.10.11.12/32")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the traffic selector.
        :param pulumi.Input[str] destination_address: Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] destination_port: Specifies the IP port used by the application. The default value is `All Ports (0)`
        :param pulumi.Input[str] direction: Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        :param pulumi.Input[int] ip_protocol: Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        :param pulumi.Input[str] ipsec_policy: Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        :param pulumi.Input[str] name: Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        :param pulumi.Input[int] order: Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
               When creating a new traffic selector, if this parameter is not specified, the default is `last`
        :param pulumi.Input[str] source_address: Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] source_port: Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrafficSelectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `TrafficSelector` Manage IPSec Traffic Selectors on BIG-IP

        Resources should be named with their "full path". The full path is the combination of the partition + name (example: /Common/test-selector)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test_selector = f5bigip.TrafficSelector("test-selector",
            name="/Common/test-selector",
            destination_address="3.10.11.2/32",
            source_address="2.10.11.12/32")
        ```

        :param str resource_name: The name of the resource.
        :param TrafficSelectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrafficSelectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 destination_address: Optional[pulumi.Input[str]] = None,
                 destination_port: Optional[pulumi.Input[int]] = None,
                 direction: Optional[pulumi.Input[str]] = None,
                 ip_protocol: Optional[pulumi.Input[int]] = None,
                 ipsec_policy: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 order: Optional[pulumi.Input[int]] = None,
                 source_address: Optional[pulumi.Input[str]] = None,
                 source_port: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrafficSelectorArgs.__new__(TrafficSelectorArgs)

            __props__.__dict__["description"] = description
            if destination_address is None and not opts.urn:
                raise TypeError("Missing required property 'destination_address'")
            __props__.__dict__["destination_address"] = destination_address
            __props__.__dict__["destination_port"] = destination_port
            __props__.__dict__["direction"] = direction
            __props__.__dict__["ip_protocol"] = ip_protocol
            __props__.__dict__["ipsec_policy"] = ipsec_policy
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["order"] = order
            if source_address is None and not opts.urn:
                raise TypeError("Missing required property 'source_address'")
            __props__.__dict__["source_address"] = source_address
            __props__.__dict__["source_port"] = source_port
        super(TrafficSelector, __self__).__init__(
            'f5bigip:index/trafficSelector:TrafficSelector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            destination_address: Optional[pulumi.Input[str]] = None,
            destination_port: Optional[pulumi.Input[int]] = None,
            direction: Optional[pulumi.Input[str]] = None,
            ip_protocol: Optional[pulumi.Input[int]] = None,
            ipsec_policy: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            order: Optional[pulumi.Input[int]] = None,
            source_address: Optional[pulumi.Input[str]] = None,
            source_port: Optional[pulumi.Input[int]] = None) -> 'TrafficSelector':
        """
        Get an existing TrafficSelector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: Description of the traffic selector.
        :param pulumi.Input[str] destination_address: Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] destination_port: Specifies the IP port used by the application. The default value is `All Ports (0)`
        :param pulumi.Input[str] direction: Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        :param pulumi.Input[int] ip_protocol: Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        :param pulumi.Input[str] ipsec_policy: Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        :param pulumi.Input[str] name: Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        :param pulumi.Input[int] order: Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
               When creating a new traffic selector, if this parameter is not specified, the default is `last`
        :param pulumi.Input[str] source_address: Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        :param pulumi.Input[int] source_port: Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrafficSelectorState.__new__(_TrafficSelectorState)

        __props__.__dict__["description"] = description
        __props__.__dict__["destination_address"] = destination_address
        __props__.__dict__["destination_port"] = destination_port
        __props__.__dict__["direction"] = direction
        __props__.__dict__["ip_protocol"] = ip_protocol
        __props__.__dict__["ipsec_policy"] = ipsec_policy
        __props__.__dict__["name"] = name
        __props__.__dict__["order"] = order
        __props__.__dict__["source_address"] = source_address
        __props__.__dict__["source_port"] = source_port
        return TrafficSelector(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        Description of the traffic selector.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationAddress")
    def destination_address(self) -> pulumi.Output[str]:
        """
        Specifies the host or network IP address to which the application traffic is destined.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "destination_address")

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> pulumi.Output[int]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`
        """
        return pulumi.get(self, "destination_port")

    @property
    @pulumi.getter
    def direction(self) -> pulumi.Output[str]:
        """
        Specifies whether the traffic selector applies to inbound or outbound traffic, or both. The default value is `Both`.
        """
        return pulumi.get(self, "direction")

    @property
    @pulumi.getter(name="ipProtocol")
    def ip_protocol(self) -> pulumi.Output[int]:
        """
        Specifies the network protocol to use for this traffic. The default value is `All Protocols (255)`
        """
        return pulumi.get(self, "ip_protocol")

    @property
    @pulumi.getter(name="ipsecPolicy")
    def ipsec_policy(self) -> pulumi.Output[str]:
        """
        Specifies the IPsec policy that tells the BIG-IP system how to handle the packets.When creating a new traffic selector, if this parameter is not specified, the default is `default-ipsec-policy`.
        """
        return pulumi.get(self, "ipsec_policy")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the IPSec traffic-selector,it should be "full path".The full path is the combination of the partition + name of the IPSec traffic-selector.(For example `/Common/test-selector`)
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def order(self) -> pulumi.Output[int]:
        """
        Specifies the order in which traffic is matched, if traffic can be matched to multiple traffic selectors.Traffic is matched to the traffic selector with the highest priority (lowest order number).
        When creating a new traffic selector, if this parameter is not specified, the default is `last`
        """
        return pulumi.get(self, "order")

    @property
    @pulumi.getter(name="sourceAddress")
    def source_address(self) -> pulumi.Output[str]:
        """
        Specifies the host or network IP address from which the application traffic originates.When creating a new traffic selector, this parameter is required.
        """
        return pulumi.get(self, "source_address")

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> pulumi.Output[int]:
        """
        Specifies the IP port used by the application. The default value is `All Ports (0)`.
        """
        return pulumi.get(self, "source_port")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['As3Args', 'As3']

@pulumi.input_type
class As3Args:
    def __init__(__self__, *,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a As3 resource.
        :param pulumi.Input[str] application_list: List of applications currently deployed on the Big-Ip
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_01": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_1": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.0.2.10"
               ],
               "pool": "web_pool"
               },
               "web_pool": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.1.100",
               "192.0.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_02": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_2": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.2.2.10"
               ],
               "pool": "web_pool2"
               },
               "web_pool2": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.2.1.100",
               "192.2.1.110"
               ]
               }
               ]
               }
               }
               },
               "Sample_03": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_3": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.1.2.10"
               ],
               "pool": "web_pool3"
               },
               "web_pool3": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.3.1.100",
               "192.3.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               
               * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)
               
               ```json
               {
               "Application1": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.2.1"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.2.10",
               "192.0.2.20"
               ]
               }
               ]
               }
               },
               "Application2": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.3.2"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.3.30",
               "192.0.3.40"
               ]
               }
               ]
               }
               }
               }
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: List of tenants currently deployed on the Big-Ip
        :param pulumi.Input[str] tenant_name: Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        if application_list is not None:
            pulumi.set(__self__, "application_list", application_list)
        if as3_json is not None:
            pulumi.set(__self__, "as3_json", as3_json)
        if ignore_metadata is not None:
            pulumi.set(__self__, "ignore_metadata", ignore_metadata)
        if task_id is not None:
            pulumi.set(__self__, "task_id", task_id)
        if tenant_filter is not None:
            pulumi.set(__self__, "tenant_filter", tenant_filter)
        if tenant_list is not None:
            pulumi.set(__self__, "tenant_list", tenant_list)
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> Optional[pulumi.Input[str]]:
        """
        List of applications currently deployed on the Big-Ip
        """
        return pulumi.get(self, "application_list")

    @application_list.setter
    def application_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_list", value)

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> Optional[pulumi.Input[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @as3_json.setter
    def as3_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "as3_json", value)

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> Optional[pulumi.Input[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_01": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_1": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.0.2.10"
        ],
        "pool": "web_pool"
        },
        "web_pool": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.1.100",
        "192.0.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_02": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_2": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.2.2.10"
        ],
        "pool": "web_pool2"
        },
        "web_pool2": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.2.1.100",
        "192.2.1.110"
        ]
        }
        ]
        }
        }
        },
        "Sample_03": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_3": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.1.2.10"
        ],
        "pool": "web_pool3"
        },
        "web_pool3": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.3.1.100",
        "192.3.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```

        * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)

        ```json
        {
        "Application1": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.2.1"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.2.10",
        "192.0.2.20"
        ]
        }
        ]
        }
        },
        "Application2": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.3.2"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.3.30",
        "192.0.3.40"
        ]
        }
        ]
        }
        }
        }
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @ignore_metadata.setter
    def ignore_metadata(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ignore_metadata", value)

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @task_id.setter
    def task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "task_id", value)

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> Optional[pulumi.Input[str]]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @tenant_filter.setter
    def tenant_filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_filter", value)

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> Optional[pulumi.Input[str]]:
        """
        List of tenants currently deployed on the Big-Ip
        """
        return pulumi.get(self, "tenant_list")

    @tenant_list.setter
    def tenant_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_list", value)

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)


@pulumi.input_type
class _As3State:
    def __init__(__self__, *,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 per_app_mode: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering As3 resources.
        :param pulumi.Input[str] application_list: List of applications currently deployed on the Big-Ip
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_01": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_1": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.0.2.10"
               ],
               "pool": "web_pool"
               },
               "web_pool": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.1.100",
               "192.0.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_02": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_2": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.2.2.10"
               ],
               "pool": "web_pool2"
               },
               "web_pool2": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.2.1.100",
               "192.2.1.110"
               ]
               }
               ]
               }
               }
               },
               "Sample_03": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_3": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.1.2.10"
               ],
               "pool": "web_pool3"
               },
               "web_pool3": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.3.1.100",
               "192.3.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               
               * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)
               
               ```json
               {
               "Application1": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.2.1"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.2.10",
               "192.0.2.20"
               ]
               }
               ]
               }
               },
               "Application2": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.3.2"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.3.30",
               "192.0.3.40"
               ]
               }
               ]
               }
               }
               }
               ```
        :param pulumi.Input[bool] per_app_mode: Will specify whether is deployment is done via Per-Application Way or Traditional Way
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: List of tenants currently deployed on the Big-Ip
        :param pulumi.Input[str] tenant_name: Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        if application_list is not None:
            pulumi.set(__self__, "application_list", application_list)
        if as3_json is not None:
            pulumi.set(__self__, "as3_json", as3_json)
        if ignore_metadata is not None:
            pulumi.set(__self__, "ignore_metadata", ignore_metadata)
        if per_app_mode is not None:
            pulumi.set(__self__, "per_app_mode", per_app_mode)
        if task_id is not None:
            pulumi.set(__self__, "task_id", task_id)
        if tenant_filter is not None:
            pulumi.set(__self__, "tenant_filter", tenant_filter)
        if tenant_list is not None:
            pulumi.set(__self__, "tenant_list", tenant_list)
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> Optional[pulumi.Input[str]]:
        """
        List of applications currently deployed on the Big-Ip
        """
        return pulumi.get(self, "application_list")

    @application_list.setter
    def application_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_list", value)

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> Optional[pulumi.Input[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @as3_json.setter
    def as3_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "as3_json", value)

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> Optional[pulumi.Input[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_01": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_1": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.0.2.10"
        ],
        "pool": "web_pool"
        },
        "web_pool": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.1.100",
        "192.0.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_02": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_2": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.2.2.10"
        ],
        "pool": "web_pool2"
        },
        "web_pool2": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.2.1.100",
        "192.2.1.110"
        ]
        }
        ]
        }
        }
        },
        "Sample_03": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_3": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.1.2.10"
        ],
        "pool": "web_pool3"
        },
        "web_pool3": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.3.1.100",
        "192.3.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```

        * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)

        ```json
        {
        "Application1": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.2.1"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.2.10",
        "192.0.2.20"
        ]
        }
        ]
        }
        },
        "Application2": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.3.2"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.3.30",
        "192.0.3.40"
        ]
        }
        ]
        }
        }
        }
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @ignore_metadata.setter
    def ignore_metadata(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ignore_metadata", value)

    @property
    @pulumi.getter(name="perAppMode")
    def per_app_mode(self) -> Optional[pulumi.Input[bool]]:
        """
        Will specify whether is deployment is done via Per-Application Way or Traditional Way
        """
        return pulumi.get(self, "per_app_mode")

    @per_app_mode.setter
    def per_app_mode(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "per_app_mode", value)

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @task_id.setter
    def task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "task_id", value)

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> Optional[pulumi.Input[str]]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @tenant_filter.setter
    def tenant_filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_filter", value)

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> Optional[pulumi.Input[str]]:
        """
        List of tenants currently deployed on the Big-Ip
        """
        return pulumi.get(self, "tenant_list")

    @tenant_list.setter
    def tenant_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_list", value)

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)


class As3(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        As3 resources can be imported using the partition name, e.g., ( use comma separated partition names if there are multiple partitions in as3 deployments )

        ```sh
        $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01
        ```

        ```sh
        $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01,Sample_non_http_01
        ```

        #### Import examples ( single and multiple partitions )

        ```sh
        $ pulumi import f5bigip:index/as3:As3 test Sample_http_01
        ```

        bigip_as3.test: Importing from ID "Sample_http_01"...

        bigip_as3.test: Import prepared!

          Prepared bigip_as3 for import

        bigip_as3.test: Refreshing state... [id=Sample_http_01]

        Import successful!

        The resources that were imported are shown above. These resources are now in

        your Terraform state and will henceforth be managed by Terraform.

        $ terraform show

        bigip_as3.test:

        resource "bigip_as3" "test" {

            as3_json      = jsonencode(
            
                {
            
                    action      = "deploy"
            
                    class       = "AS3"
            
                    declaration = {
            
                        Sample_http_01 = {
            
                            A1    = {
            
                                class      = "Application"
            
                                jsessionid = {
            
                                    class             = "Persist"
            
                                    cookieMethod      = "hash"
            
                                    cookieName        = "JSESSIONID"
            
                                    persistenceMethod = "cookie"
            
                                }
            
                                service    = {
            
                                    class              = "Service_HTTP"
            
                                    persistenceMethods = [
            
                                        {
            
                                            use = "jsessionid"
            
                                        },
            
                                    ]
            
                                    pool               = "web_pool"
            
                                    virtualAddresses   = [
            
                                        "10.0.2.10",
            
                                    ]
            
                                }
            
                                web_pool   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "192.0.2.10",
            
                                                "192.0.2.11",
            
                                            ]
            
                                            servicePort     = 80
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "http",
            
                                    ]
            
                                }
            
                            }
            
                            class = "Tenant"
            
                        }
            
                        class          = "ADC"
            
                        id             = "UDP_DNS_Sample"
            
                        label          = "UDP_DNS_Sample"
            
                        remark         = "Sample of a UDP DNS Load Balancer Service"
            
                        schemaVersion  = "3.0.0"
            
                    }
            
                    persist     = true
            
                }
            
            )
            
            id            = "Sample_http_01"
            
            tenant_filter = "Sample_http_01"
            
            tenant_list   = "Sample_http_01"

        }

        ```sh
        $ pulumi import f5bigip:index/as3:As3 test Sample_http_01,Sample_non_http_01
        ```

        bigip_as3.test: Importing from ID "Sample_http_01,Sample_non_http_01"...

        bigip_as3.test: Import prepared!

          Prepared bigip_as3 for import

        bigip_as3.test: Refreshing state... [id=Sample_http_01,Sample_non_http_01]

        Import successful!

        The resources that were imported are shown above. These resources are now in

        your Terraform state and will henceforth be managed by Terraform.

        $ terraform show

        bigip_as3.test:

        resource "bigip_as3" "test" {

            as3_json      = jsonencode(
            
                {
            
                    action      = "deploy"
            
                    class       = "AS3"
            
                    declaration = {
            
                        Sample_http_01     = {
            
                            A1    = {
            
                                class      = "Application"
            
                                jsessionid = {
            
                                    class             = "Persist"
            
                                    cookieMethod      = "hash"
            
                                    cookieName        = "JSESSIONID"
            
                                    persistenceMethod = "cookie"
            
                                }
            
                                service    = {
            
                                    class              = "Service_HTTP"
            
                                    persistenceMethods = [
            
                                        {
            
                                            use = "jsessionid"
            
                                        },
            
                                    ]
            
                                    pool               = "web_pool"
            
                                    virtualAddresses   = [
            
                                        "10.0.2.10",
            
                                    ]
            
                                }
            
                                web_pool   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "192.0.2.10",
            
                                                "192.0.2.11",
            
                                            ]
            
                                            servicePort     = 80
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "http",
            
                                    ]
            
                                }
            
                            }
            
                            class = "Tenant"
            
                        }
            
                        Sample_non_http_01 = {
            
                            DNS_Service = {
            
                                Pool1   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "10.1.10.100",
            
                                            ]
            
                                            servicePort     = 53
            
                                        },
            
                                        {
            
                                            serverAddresses = [
            
                                                "10.1.10.101",
            
                                            ]
            
                                            servicePort     = 53
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "icmp",
            
                                    ]
            
                                }
            
                                class   = "Application"
            
                                service = {
            
                                    class            = "Service_UDP"
            
                                    pool             = "Pool1"
            
                                    virtualAddresses = [
            
                                        "10.1.20.121",
            
                                    ]
            
                                    virtualPort      = 53
            
                                }
            
                            }
            
                            class       = "Tenant"
            
                        }
            
                        class              = "ADC"
            
                        id                 = "UDP_DNS_Sample"
            
                        label              = "UDP_DNS_Sample"
            
                        remark             = "Sample of a UDP DNS Load Balancer Service"
            
                        schemaVersion      = "3.0.0"
            
                    }
            
                    persist     = true
            
                }
            
            )
            
            id            = "Sample_http_01,Sample_non_http_01"
            
            tenant_filter = "Sample_http_01,Sample_non_http_01"
            
            tenant_list   = "Sample_http_01,Sample_non_http_01"

        }

        * `AS3 documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/userguide/composing-a-declaration.html

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_list: List of applications currently deployed on the Big-Ip
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_01": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_1": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.0.2.10"
               ],
               "pool": "web_pool"
               },
               "web_pool": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.1.100",
               "192.0.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_02": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_2": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.2.2.10"
               ],
               "pool": "web_pool2"
               },
               "web_pool2": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.2.1.100",
               "192.2.1.110"
               ]
               }
               ]
               }
               }
               },
               "Sample_03": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_3": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.1.2.10"
               ],
               "pool": "web_pool3"
               },
               "web_pool3": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.3.1.100",
               "192.3.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               
               * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)
               
               ```json
               {
               "Application1": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.2.1"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.2.10",
               "192.0.2.20"
               ]
               }
               ]
               }
               },
               "Application2": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.3.2"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.3.30",
               "192.0.3.40"
               ]
               }
               ]
               }
               }
               }
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: List of tenants currently deployed on the Big-Ip
        :param pulumi.Input[str] tenant_name: Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[As3Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        As3 resources can be imported using the partition name, e.g., ( use comma separated partition names if there are multiple partitions in as3 deployments )

        ```sh
        $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01
        ```

        ```sh
        $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01,Sample_non_http_01
        ```

        #### Import examples ( single and multiple partitions )

        ```sh
        $ pulumi import f5bigip:index/as3:As3 test Sample_http_01
        ```

        bigip_as3.test: Importing from ID "Sample_http_01"...

        bigip_as3.test: Import prepared!

          Prepared bigip_as3 for import

        bigip_as3.test: Refreshing state... [id=Sample_http_01]

        Import successful!

        The resources that were imported are shown above. These resources are now in

        your Terraform state and will henceforth be managed by Terraform.

        $ terraform show

        bigip_as3.test:

        resource "bigip_as3" "test" {

            as3_json      = jsonencode(
            
                {
            
                    action      = "deploy"
            
                    class       = "AS3"
            
                    declaration = {
            
                        Sample_http_01 = {
            
                            A1    = {
            
                                class      = "Application"
            
                                jsessionid = {
            
                                    class             = "Persist"
            
                                    cookieMethod      = "hash"
            
                                    cookieName        = "JSESSIONID"
            
                                    persistenceMethod = "cookie"
            
                                }
            
                                service    = {
            
                                    class              = "Service_HTTP"
            
                                    persistenceMethods = [
            
                                        {
            
                                            use = "jsessionid"
            
                                        },
            
                                    ]
            
                                    pool               = "web_pool"
            
                                    virtualAddresses   = [
            
                                        "10.0.2.10",
            
                                    ]
            
                                }
            
                                web_pool   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "192.0.2.10",
            
                                                "192.0.2.11",
            
                                            ]
            
                                            servicePort     = 80
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "http",
            
                                    ]
            
                                }
            
                            }
            
                            class = "Tenant"
            
                        }
            
                        class          = "ADC"
            
                        id             = "UDP_DNS_Sample"
            
                        label          = "UDP_DNS_Sample"
            
                        remark         = "Sample of a UDP DNS Load Balancer Service"
            
                        schemaVersion  = "3.0.0"
            
                    }
            
                    persist     = true
            
                }
            
            )
            
            id            = "Sample_http_01"
            
            tenant_filter = "Sample_http_01"
            
            tenant_list   = "Sample_http_01"

        }

        ```sh
        $ pulumi import f5bigip:index/as3:As3 test Sample_http_01,Sample_non_http_01
        ```

        bigip_as3.test: Importing from ID "Sample_http_01,Sample_non_http_01"...

        bigip_as3.test: Import prepared!

          Prepared bigip_as3 for import

        bigip_as3.test: Refreshing state... [id=Sample_http_01,Sample_non_http_01]

        Import successful!

        The resources that were imported are shown above. These resources are now in

        your Terraform state and will henceforth be managed by Terraform.

        $ terraform show

        bigip_as3.test:

        resource "bigip_as3" "test" {

            as3_json      = jsonencode(
            
                {
            
                    action      = "deploy"
            
                    class       = "AS3"
            
                    declaration = {
            
                        Sample_http_01     = {
            
                            A1    = {
            
                                class      = "Application"
            
                                jsessionid = {
            
                                    class             = "Persist"
            
                                    cookieMethod      = "hash"
            
                                    cookieName        = "JSESSIONID"
            
                                    persistenceMethod = "cookie"
            
                                }
            
                                service    = {
            
                                    class              = "Service_HTTP"
            
                                    persistenceMethods = [
            
                                        {
            
                                            use = "jsessionid"
            
                                        },
            
                                    ]
            
                                    pool               = "web_pool"
            
                                    virtualAddresses   = [
            
                                        "10.0.2.10",
            
                                    ]
            
                                }
            
                                web_pool   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "192.0.2.10",
            
                                                "192.0.2.11",
            
                                            ]
            
                                            servicePort     = 80
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "http",
            
                                    ]
            
                                }
            
                            }
            
                            class = "Tenant"
            
                        }
            
                        Sample_non_http_01 = {
            
                            DNS_Service = {
            
                                Pool1   = {
            
                                    class    = "Pool"
            
                                    members  = [
            
                                        {
            
                                            serverAddresses = [
            
                                                "10.1.10.100",
            
                                            ]
            
                                            servicePort     = 53
            
                                        },
            
                                        {
            
                                            serverAddresses = [
            
                                                "10.1.10.101",
            
                                            ]
            
                                            servicePort     = 53
            
                                        },
            
                                    ]
            
                                    monitors = [
            
                                        "icmp",
            
                                    ]
            
                                }
            
                                class   = "Application"
            
                                service = {
            
                                    class            = "Service_UDP"
            
                                    pool             = "Pool1"
            
                                    virtualAddresses = [
            
                                        "10.1.20.121",
            
                                    ]
            
                                    virtualPort      = 53
            
                                }
            
                            }
            
                            class       = "Tenant"
            
                        }
            
                        class              = "ADC"
            
                        id                 = "UDP_DNS_Sample"
            
                        label              = "UDP_DNS_Sample"
            
                        remark             = "Sample of a UDP DNS Load Balancer Service"
            
                        schemaVersion      = "3.0.0"
            
                    }
            
                    persist     = true
            
                }
            
            )
            
            id            = "Sample_http_01,Sample_non_http_01"
            
            tenant_filter = "Sample_http_01,Sample_non_http_01"
            
            tenant_list   = "Sample_http_01,Sample_non_http_01"

        }

        * `AS3 documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/userguide/composing-a-declaration.html

        :param str resource_name: The name of the resource.
        :param As3Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(As3Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = As3Args.__new__(As3Args)

            __props__.__dict__["application_list"] = application_list
            __props__.__dict__["as3_json"] = as3_json
            __props__.__dict__["ignore_metadata"] = ignore_metadata
            __props__.__dict__["task_id"] = task_id
            __props__.__dict__["tenant_filter"] = tenant_filter
            __props__.__dict__["tenant_list"] = tenant_list
            __props__.__dict__["tenant_name"] = tenant_name
            __props__.__dict__["per_app_mode"] = None
        super(As3, __self__).__init__(
            'f5bigip:index/as3:As3',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_list: Optional[pulumi.Input[str]] = None,
            as3_json: Optional[pulumi.Input[str]] = None,
            ignore_metadata: Optional[pulumi.Input[bool]] = None,
            per_app_mode: Optional[pulumi.Input[bool]] = None,
            task_id: Optional[pulumi.Input[str]] = None,
            tenant_filter: Optional[pulumi.Input[str]] = None,
            tenant_list: Optional[pulumi.Input[str]] = None,
            tenant_name: Optional[pulumi.Input[str]] = None) -> 'As3':
        """
        Get an existing As3 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_list: List of applications currently deployed on the Big-Ip
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_01": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_1": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.0.2.10"
               ],
               "pool": "web_pool"
               },
               "web_pool": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.1.100",
               "192.0.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```json
               
               {
               "class": "AS3",
               "action": "deploy",
               "persist": true,
               "declaration": {
               "class": "ADC",
               "schemaVersion": "3.0.0",
               "id": "example-declaration-01",
               "label": "Sample 1",
               "remark": "Simple HTTP application with round robin pool",
               "Sample_02": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_2": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.2.2.10"
               ],
               "pool": "web_pool2"
               },
               "web_pool2": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.2.1.100",
               "192.2.1.110"
               ]
               }
               ]
               }
               }
               },
               "Sample_03": {
               "class": "Tenant",
               "defaultRouteDomain": 0,
               "Application_3": {
               "class": "Application",
               "template": "http",
               "serviceMain": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "10.1.2.10"
               ],
               "pool": "web_pool3"
               },
               "web_pool3": {
               "class": "Pool",
               "monitors": [
               "http"
               ],
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.3.1.100",
               "192.3.1.110"
               ]
               }
               ]
               }
               }
               }
               }
               }
               
               ```
               
               * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)
               
               ```json
               {
               "Application1": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.2.1"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.2.10",
               "192.0.2.20"
               ]
               }
               ]
               }
               },
               "Application2": {
               "class": "Application",
               "service": {
               "class": "Service_HTTP",
               "virtualAddresses": [
               "192.0.3.2"
               ],
               "pool": "pool"
               },
               "pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 80,
               "serverAddresses": [
               "192.0.3.30",
               "192.0.3.40"
               ]
               }
               ]
               }
               }
               }
               ```
        :param pulumi.Input[bool] per_app_mode: Will specify whether is deployment is done via Per-Application Way or Traditional Way
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: List of tenants currently deployed on the Big-Ip
        :param pulumi.Input[str] tenant_name: Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _As3State.__new__(_As3State)

        __props__.__dict__["application_list"] = application_list
        __props__.__dict__["as3_json"] = as3_json
        __props__.__dict__["ignore_metadata"] = ignore_metadata
        __props__.__dict__["per_app_mode"] = per_app_mode
        __props__.__dict__["task_id"] = task_id
        __props__.__dict__["tenant_filter"] = tenant_filter
        __props__.__dict__["tenant_list"] = tenant_list
        __props__.__dict__["tenant_name"] = tenant_name
        return As3(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> pulumi.Output[str]:
        """
        List of applications currently deployed on the Big-Ip
        """
        return pulumi.get(self, "application_list")

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> pulumi.Output[Optional[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> pulumi.Output[Optional[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_01": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_1": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.0.2.10"
        ],
        "pool": "web_pool"
        },
        "web_pool": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.1.100",
        "192.0.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```json

        {
        "class": "AS3",
        "action": "deploy",
        "persist": true,
        "declaration": {
        "class": "ADC",
        "schemaVersion": "3.0.0",
        "id": "example-declaration-01",
        "label": "Sample 1",
        "remark": "Simple HTTP application with round robin pool",
        "Sample_02": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_2": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.2.2.10"
        ],
        "pool": "web_pool2"
        },
        "web_pool2": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.2.1.100",
        "192.2.1.110"
        ]
        }
        ]
        }
        }
        },
        "Sample_03": {
        "class": "Tenant",
        "defaultRouteDomain": 0,
        "Application_3": {
        "class": "Application",
        "template": "http",
        "serviceMain": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "10.1.2.10"
        ],
        "pool": "web_pool3"
        },
        "web_pool3": {
        "class": "Pool",
        "monitors": [
        "http"
        ],
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.3.1.100",
        "192.3.1.110"
        ]
        }
        ]
        }
        }
        }
        }
        }

        ```

        * `perApplication_example` - Per Application Example - JSON file with multiple Applications (and no Tenant Details)

        ```json
        {
        "Application1": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.2.1"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.2.10",
        "192.0.2.20"
        ]
        }
        ]
        }
        },
        "Application2": {
        "class": "Application",
        "service": {
        "class": "Service_HTTP",
        "virtualAddresses": [
        "192.0.3.2"
        ],
        "pool": "pool"
        },
        "pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 80,
        "serverAddresses": [
        "192.0.3.30",
        "192.0.3.40"
        ]
        }
        ]
        }
        }
        }
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @property
    @pulumi.getter(name="perAppMode")
    def per_app_mode(self) -> pulumi.Output[bool]:
        """
        Will specify whether is deployment is done via Per-Application Way or Traditional Way
        """
        return pulumi.get(self, "per_app_mode")

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> pulumi.Output[str]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> pulumi.Output[str]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> pulumi.Output[str]:
        """
        List of tenants currently deployed on the Big-Ip
        """
        return pulumi.get(self, "tenant_list")

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> pulumi.Output[str]:
        """
        Name of Tenant. This name is used only in the case of Per-Application Deployment. If it is not provided, then a random name would be generated.
        """
        return pulumi.get(self, "tenant_name")

